SLACtrac
========

SLACtrac is designed to fill a gap in linear accelerator simulation
software in Python. SLACtrac generates transfer matrices which can
be used to transfer particle distributions through a linac.
